| Name                               | Version         | License                                                                                          | URL                                                                                                         |
|------------------------------------|-----------------|--------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------|
| ImageHash                          | 4.3.2           | 2-clause BSD License                                                                             | https://github.com/JohannesBuchner/imagehash                                                                |
| Jinja2                             | 3.1.6           | BSD License                                                                                      | https://github.com/pallets/jinja/                                                                           |
| Markdown                           | 3.10.2          | BSD-3-Clause                                                                                     | https://Python-Markdown.github.io/                                                                          |
| MarkupSafe                         | 3.0.3           | BSD-3-Clause                                                                                     | https://github.com/pallets/markupsafe/                                                                      |
| PyJWT                              | 2.11.0          | MIT                                                                                              | https://github.com/jpadilla/pyjwt                                                                           |
| PyWavelets                         | 1.9.0           | MIT AND BSD-3-Clause                                                                             | https://github.com/PyWavelets/pywt                                                                          |
| PyYAML                             | 6.0.3           | MIT License                                                                                      | https://pyyaml.org/                                                                                         |
| Pygments                           | 2.19.2          | BSD License                                                                                      | https://pygments.org                                                                                        |
| SQLAlchemy                         | 1.4.54          | MIT License                                                                                      | https://www.sqlalchemy.org                                                                                  |
| Send2Trash                         | 2.1.0           | BSD-3-Clause                                                                                     | https://github.com/arsenetar/send2trash                                                                     |
| aiohappyeyeballs                   | 2.6.1           | Python Software Foundation License                                                               | https://github.com/aio-libs/aiohappyeyeballs                                                                |
| aiohttp                            | 3.13.3          | Apache-2.0 AND MIT                                                                               | https://github.com/aio-libs/aiohttp                                                                         |
| aiohttp-cors                       | 0.8.1           | Apache Software License                                                                          | https://github.com/aio-libs/aiohttp-cors                                                                    |
| aiohttp-jinja2                     | 1.6             | Apache Software License                                                                          | https://github.com/aio-libs/aiohttp_jinja2/                                                                 |
| aiosignal                          | 1.4.0           | Apache Software License                                                                          | https://github.com/aio-libs/aiosignal                                                                       |
| annotated-types                    | 0.7.0           | MIT License                                                                                      | https://github.com/annotated-types/annotated-types                                                          |
| anyascii                           | 0.3.3           | ISC License (ISCL)                                                                               | https://github.com/anyascii/anyascii                                                                        |
| anyio                              | 4.12.1          | MIT                                                                                              | https://anyio.readthedocs.io/en/stable/versionhistory.html                                                  |
| appnope                            | 0.1.4           | BSD License                                                                                      | http://github.com/minrk/appnope                                                                             |
| argon2-cffi                        | 25.1.0          | MIT                                                                                              | https://github.com/hynek/argon2-cffi/blob/main/CHANGELOG.md                                                 |
| argon2-cffi-bindings               | 25.1.0          | MIT                                                                                              | https://github.com/hynek/argon2-cffi-bindings/blob/main/CHANGELOG.md                                        |
| arrow                              | 1.4.0           | Apache Software License                                                                          | https://github.com/arrow-py/arrow                                                                           |
| asttokens                          | 3.0.1           | Apache 2.0                                                                                       | https://github.com/gristlabs/asttokens                                                                      |
| async-lru                          | 2.2.0           | MIT License                                                                                      | https://github.com/aio-libs/async-lru                                                                       |
| attrs                              | 24.3.0          | MIT                                                                                              | https://www.attrs.org/en/stable/changelog.html                                                              |
| awscli                             | 1.44.44         | Apache Software License                                                                          | http://aws.amazon.com/cli/                                                                                  |
| azure-core                         | 1.38.2          | MIT License                                                                                      | https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/core/azure-core                                 |
| azure-identity                     | 1.26.0b2        | MIT                                                                                              | https://github.com/Azure/azure-sdk-for-python                                                               |
| azure-storage-blob                 | 12.29.0b1       | MIT License                                                                                      | https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/storage/azure-storage-blob                      |
| babel                              | 2.18.0          | BSD License                                                                                      | https://babel.pocoo.org/                                                                                    |
| backrefs                           | 6.2             | MIT                                                                                              | https://github.com/facelessuser/backrefs                                                                    |
| beautifulsoup4                     | 4.14.3          | MIT License                                                                                      | https://www.crummy.com/software/BeautifulSoup/bs4/                                                          |
| bidict                             | 0.23.1          | Mozilla Public License 2.0 (MPL 2.0)                                                             | https://github.com/jab/bidict                                                                               |
| bleach                             | 6.3.0           | Apache Software License                                                                          | https://github.com/mozilla/bleach                                                                           |
| boto3                              | 1.42.54         | Apache-2.0                                                                                       | https://github.com/boto/boto3                                                                               |
| boto3-stubs                        | 1.42.54         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| botocore                           | 1.42.54         | Apache-2.0                                                                                       | https://github.com/boto/botocore                                                                            |
| botocore-stubs                     | 1.42.41         | MIT                                                                                              | https://github.com/youtype/botocore-stubs                                                                   |
| bracex                             | 2.6             | MIT                                                                                              | https://github.com/facelessuser/bracex                                                                      |
| bump-my-version                    | 1.2.7           | MIT License                                                                                      | https://github.com/callowayproject/bump-my-version                                                          |
| cattrs                             | 26.1.0          | MIT License                                                                                      | https://catt.rs                                                                                             |
| certifi                            | 2026.1.4        | Mozilla Public License 2.0 (MPL 2.0)                                                             | https://github.com/certifi/python-certifi                                                                   |
| cffi                               | 2.0.0           | MIT                                                                                              | https://cffi.readthedocs.io/en/latest/whatsnew.html                                                         |
| charset-normalizer                 | 3.4.4           | MIT                                                                                              | https://github.com/jawah/charset_normalizer/blob/master/CHANGELOG.md                                        |
| click                              | 8.3.1           | BSD-3-Clause                                                                                     | https://github.com/pallets/click/                                                                           |
| cloudpickle                        | 3.1.2           | BSD License                                                                                      | https://github.com/cloudpipe/cloudpickle                                                                    |
| colorama                           | 0.4.6           | BSD License                                                                                      | https://github.com/tartley/colorama                                                                         |
| coloredlogs                        | 15.0.1          | MIT License                                                                                      | https://coloredlogs.readthedocs.io                                                                          |
| colorful                           | 0.6.0a1         | MIT License                                                                                      | http://github.com/timofurrer/colorful                                                                       |
| comm                               | 0.2.3           | BSD License                                                                                      | https://github.com/ipython/comm                                                                             |
| coverage                           | 7.13.4          | Apache-2.0                                                                                       | https://github.com/coveragepy/coveragepy                                                                    |
| cryptography                       | 46.0.5          | Apache-2.0 OR BSD-3-Clause                                                                       | https://github.com/pyca/cryptography                                                                        |
| debugpy                            | 1.8.20          | MIT License                                                                                      | https://aka.ms/debugpy                                                                                      |
| decorator                          | 5.2.1           | BSD License                                                                                      | UNKNOWN                                                                                                     |
| defusedxml                         | 0.8.0rc2        | Python Software Foundation License                                                               | https://github.com/tiran/defusedxml                                                                         |
| deprecation                        | 2.1.0           | Apache Software License                                                                          | http://deprecation.readthedocs.io/                                                                          |
| dill                               | 0.3.8           | BSD License                                                                                      | https://github.com/uqfoundation/dill                                                                        |
| distlib                            | 0.4.0           | Python Software Foundation License                                                               | https://github.com/pypa/distlib                                                                             |
| distro                             | 1.9.0           | Apache Software License                                                                          | https://github.com/python-distro/distro                                                                     |
| docker                             | 7.1.0           | Apache-2.0                                                                                       | https://github.com/docker/docker-py                                                                         |
| docutils                           | 0.19            | BSD License; GNU General Public License (GPL); Public Domain; Python Software Foundation License | https://docutils.sourceforge.io/                                                                            |
| durationpy                         | 0.10            | MIT                                                                                              | https://github.com/icholy/durationpy                                                                        |
| emoji                              | 2.15.0          | BSD License                                                                                      | https://github.com/carpedm20/emoji/                                                                         |
| execnet                            | 2.1.2           | MIT                                                                                              | https://execnet.readthedocs.io/en/latest/                                                                   |
| executing                          | 2.2.1           | MIT License                                                                                      | https://github.com/alexmojaki/executing                                                                     |
| fastjsonschema                     | 2.21.2          | BSD License                                                                                      | https://github.com/horejsek/python-fastjsonschema                                                           |
| filelock                           | 3.24.3          | MIT                                                                                              | https://github.com/tox-dev/py-filelock                                                                      |
| flatbuffers                        | 25.12.19        | Apache Software License                                                                          | https://google.github.io/flatbuffers/                                                                       |
| flightsql-dbapi                    | 0.2.2           | Apache Software License                                                                          | https://github.com/influxdata/flightsql-dbapi                                                               |
| fqdn                               | 1.5.1           | Mozilla Public License 2.0 (MPL 2.0)                                                             | https://github.com/ypcrts/fqdn                                                                              |
| frozenlist                         | 1.8.0           | Apache-2.0                                                                                       | https://github.com/aio-libs/frozenlist                                                                      |
| fsspec                             | 2025.3.0        | BSD License                                                                                      | https://github.com/fsspec/filesystem_spec                                                                   |
| ftfy                               | 6.3.1           | Apache-2.0                                                                                       | https://ftfy.readthedocs.io/en/latest/                                                                      |
| geneva                             | 0.10.3b2        | LicenseRef-Proprietary                                                                           | UNKNOWN                                                                                                     |
| ghp-import                         | 2.1.0           | Apache Software License                                                                          | https://github.com/c-w/ghp-import                                                                           |
| google-api-core                    | 2.30.0          | Apache Software License                                                                          | https://github.com/googleapis/google-cloud-python/tree/main/packages/google-api-core                        |
| google-auth                        | 2.49.0.dev0     | Apache Software License                                                                          | https://github.com/googleapis/google-auth-library-python                                                    |
| google-cloud-core                  | 2.5.0           | Apache Software License                                                                          | https://github.com/googleapis/python-cloud-core                                                             |
| google-cloud-storage               | 3.9.0           | Apache Software License                                                                          | https://github.com/googleapis/python-storage                                                                |
| google-crc32c                      | 1.8.0           | UNKNOWN                                                                                          | https://github.com/googleapis/python-crc32c                                                                 |
| google-genai                       | 1.64.0          | Apache-2.0                                                                                       | https://github.com/googleapis/python-genai                                                                  |
| google-resumable-media             | 2.8.0           | Apache Software License                                                                          | https://github.com/googleapis/google-resumable-media-python                                                 |
| googleapis-common-protos           | 1.72.0          | Apache Software License                                                                          | https://github.com/googleapis/google-cloud-python/tree/main/packages/googleapis-common-protos               |
| griffelib                          | 2.0.0           | ISC                                                                                              | UNKNOWN                                                                                                     |
| grpcio                             | 1.78.1          | Apache-2.0                                                                                       | https://grpc.io                                                                                             |
| h11                                | 0.16.0          | MIT License                                                                                      | https://github.com/python-hyper/h11                                                                         |
| hf-xet                             | 1.3.0b0         | Apache-2.0                                                                                       | https://github.com/huggingface/xet-core                                                                     |
| httpcore                           | 1.0.9           | BSD-3-Clause                                                                                     | https://www.encode.io/httpcore/                                                                             |
| httpx                              | 0.28.1          | BSD License                                                                                      | https://github.com/encode/httpx                                                                             |
| huggingface_hub                    | 0.36.2          | Apache Software License                                                                          | https://github.com/huggingface/huggingface_hub                                                              |
| humanfriendly                      | 10.0            | MIT License                                                                                      | https://humanfriendly.readthedocs.io                                                                        |
| idna                               | 3.11            | BSD-3-Clause                                                                                     | https://github.com/kjd/idna                                                                                 |
| importlib_metadata                 | 8.7.1           | Apache-2.0                                                                                       | https://github.com/python/importlib_metadata                                                                |
| inflect                            | 7.5.0           | MIT License                                                                                      | https://github.com/jaraco/inflect                                                                           |
| iniconfig                          | 2.3.0           | MIT                                                                                              | https://github.com/pytest-dev/iniconfig                                                                     |
| ipykernel                          | 7.2.0           | BSD-3-Clause                                                                                     | https://ipython.org                                                                                         |
| ipython                            | 9.10.0          | BSD-3-Clause                                                                                     | https://ipython.org                                                                                         |
| ipython_pygments_lexers            | 1.1.1           | BSD License                                                                                      | https://github.com/ipython/ipython-pygments-lexers                                                          |
| ipywidgets                         | 8.1.8           | BSD License                                                                                      | http://jupyter.org                                                                                          |
| isodate                            | 0.7.2           | BSD License                                                                                      | https://github.com/gweis/isodate/                                                                           |
| isoduration                        | 20.11.0         | ISC License (ISCL)                                                                               | https://github.com/bolsote/isoduration                                                                      |
| jedi                               | 0.19.2          | MIT License                                                                                      | https://github.com/davidhalter/jedi                                                                         |
| jiter                              | 0.13.0          | MIT License                                                                                      | https://github.com/pydantic/jiter/                                                                          |
| jmespath                           | 1.1.0           | MIT License                                                                                      | https://github.com/jmespath/jmespath.py                                                                     |
| joblib                             | 1.5.3           | BSD-3-Clause                                                                                     | https://joblib.readthedocs.io                                                                               |
| json5                              | 0.13.0          | Apache Software License                                                                          | https://github.com/dpranke/pyjson5                                                                          |
| jsonpatch                          | 1.33            | BSD License                                                                                      | https://github.com/stefankoegl/python-json-patch                                                            |
| jsonpointer                        | 3.0.0           | BSD License                                                                                      | https://github.com/stefankoegl/python-json-pointer                                                          |
| jsonschema                         | 4.26.0          | MIT                                                                                              | https://github.com/python-jsonschema/jsonschema                                                             |
| jsonschema-specifications          | 2025.9.1        | MIT                                                                                              | https://github.com/python-jsonschema/jsonschema-specifications                                              |
| jupyter-events                     | 0.12.0          | BSD License                                                                                      | http://jupyter.org                                                                                          |
| jupyter-lsp                        | 2.3.0           | BSD License                                                                                      | https://github.com/jupyter-lsp/jupyterlab-lsp/issues                                                        |
| jupyter_client                     | 8.8.0           | BSD License                                                                                      | https://jupyter.org                                                                                         |
| jupyter_core                       | 5.9.1           | BSD-3-Clause                                                                                     | https://jupyter.org                                                                                         |
| jupyter_server                     | 2.17.0          | BSD License                                                                                      | https://jupyter-server.readthedocs.io                                                                       |
| jupyter_server_terminals           | 0.5.4           | BSD License                                                                                      | https://jupyter.org                                                                                         |
| jupyterlab                         | 4.6.0a3         | BSD License                                                                                      | https://jupyter.org                                                                                         |
| jupyterlab_pygments                | 0.3.0           | BSD License                                                                                      | https://github.com/jupyterlab/jupyterlab_pygments                                                           |
| jupyterlab_server                  | 2.28.0          | BSD License                                                                                      | https://jupyterlab-server.readthedocs.io                                                                    |
| jupyterlab_widgets                 | 3.0.16          | BSD License                                                                                      | https://github.com/jupyter-widgets/ipywidgets                                                               |
| kubernetes                         | 35.0.0          | Apache Software License                                                                          | https://github.com/kubernetes-client/python                                                                 |
| lance-namespace                    | 0.5.2           | Apache-2.0                                                                                       | https://github.com/lance-format/lance-namespace                                                             |
| lance-namespace-urllib3-client     | 0.5.2           | Apache-2.0                                                                                       | https://github.com/lance-format/lance-namespace                                                             |
| lancedb                            | 0.30.0b2        | Apache Software License                                                                          | https://github.com/lancedb/lancedb                                                                          |
| langchain-core                     | 1.2.15          | MIT License                                                                                      | https://docs.langchain.com/                                                                                 |
| langchain-text-splitters           | 1.1.1           | MIT License                                                                                      | https://docs.langchain.com/                                                                                 |
| langsmith                          | 0.7.6           | MIT                                                                                              | https://smith.langchain.com/                                                                                |
| lark                               | 1.3.1           | MIT License                                                                                      | https://github.com/lark-parser/lark                                                                         |
| librt                              | 0.8.1           | MIT License                                                                                      | https://github.com/mypyc/librt                                                                              |
| linkify-it-py                      | 2.0.3           | MIT License                                                                                      | https://github.com/tsutsu3/linkify-it-py                                                                    |
| markdown-it-py                     | 4.0.0           | MIT License                                                                                      | https://github.com/executablebooks/markdown-it-py                                                           |
| matplotlib-inline                  | 0.2.1           | UNKNOWN                                                                                          | https://github.com/ipython/matplotlib-inline                                                                |
| mdit-py-plugins                    | 0.5.0           | MIT License                                                                                      | https://github.com/executablebooks/mdit-py-plugins                                                          |
| mdurl                              | 0.1.2           | MIT License                                                                                      | https://github.com/executablebooks/mdurl                                                                    |
| mergedeep                          | 1.3.4           | MIT License                                                                                      | https://github.com/clarketm/mergedeep                                                                       |
| mistune                            | 3.2.0           | BSD License                                                                                      | https://github.com/lepture/mistune                                                                          |
| mkdocs                             | 1.6.1           | BSD-2-Clause                                                                                     | https://github.com/mkdocs/mkdocs                                                                            |
| mkdocs-autorefs                    | 1.4.4           | ISC                                                                                              | https://mkdocstrings.github.io/autorefs                                                                     |
| mkdocs-get-deps                    | 0.2.0           | MIT                                                                                              | https://github.com/mkdocs/get-deps                                                                          |
| mkdocs-material                    | 9.7.2           | MIT                                                                                              | https://github.com/squidfunk/mkdocs-material                                                                |
| mkdocs-material-extensions         | 1.3.1           | MIT                                                                                              | https://github.com/facelessuser/mkdocs-material-extensions                                                  |
| mkdocstrings                       | 1.0.3           | ISC                                                                                              | https://mkdocstrings.github.io                                                                              |
| mkdocstrings-python                | 2.0.3           | ISC                                                                                              | https://mkdocstrings.github.io/python                                                                       |
| more-itertools                     | 10.8.0          | MIT                                                                                              | https://github.com/more-itertools/more-itertools                                                            |
| mpmath                             | 1.3.0           | BSD License                                                                                      | http://mpmath.org/                                                                                          |
| msal                               | 1.35.0b1        | MIT License                                                                                      | https://github.com/AzureAD/microsoft-authentication-library-for-python                                      |
| msal-extensions                    | 1.3.1           | MIT License                                                                                      | https://github.com/AzureAD/microsoft-authentication-extensions-for-python/releases                          |
| msgpack                            | 1.1.2           | Apache-2.0                                                                                       | https://msgpack.org/                                                                                        |
| multidict                          | 6.7.1           | Apache License 2.0                                                                               | https://github.com/aio-libs/multidict                                                                       |
| multiprocess                       | 0.70.16         | BSD License                                                                                      | https://github.com/uqfoundation/multiprocess                                                                |
| mypy                               | 1.19.1          | MIT License                                                                                      | https://www.mypy-lang.org/                                                                                  |
| mypy-boto3-cloudformation          | 1.42.3          | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-dynamodb                | 1.42.41         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-ec2                     | 1.42.51         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-lambda                  | 1.42.37         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-rds                     | 1.42.51         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-s3                      | 1.42.37         | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy-boto3-sqs                     | 1.42.3          | MIT                                                                                              | https://github.com/youtype/mypy_boto3_builder                                                               |
| mypy_extensions                    | 1.1.0           | MIT                                                                                              | https://github.com/python/mypy_extensions                                                                   |
| nbclient                           | 0.10.4          | BSD License                                                                                      | https://jupyter.org                                                                                         |
| nbconvert                          | 7.17.0          | BSD License                                                                                      | https://jupyter.org                                                                                         |
| nbformat                           | 5.10.4          | BSD License                                                                                      | https://jupyter.org                                                                                         |
| nest-asyncio                       | 1.6.0           | BSD License                                                                                      | https://github.com/erdewit/nest_asyncio                                                                     |
| networkx                           | 3.6.1           | BSD-3-Clause                                                                                     | https://networkx.org/                                                                                       |
| nltk                               | 3.9.3           | Apache Software License                                                                          | https://www.nltk.org/                                                                                       |
| nodeenv                            | 1.10.0          | BSD License                                                                                      | https://github.com/ekalinin/nodeenv                                                                         |
| nodejs-wheel-binaries              | 25.5.0rc0       | MIT License                                                                                      | https://github.com/njzjz/nodejs-wheel                                                                       |
| notebook_shim                      | 0.2.4           | BSD License                                                                                      | UNKNOWN                                                                                                     |
| numpy                              | 1.26.4          | BSD License                                                                                      | https://numpy.org                                                                                           |
| oauthlib                           | 3.3.1           | BSD-3-Clause                                                                                     | https://github.com/oauthlib/oauthlib                                                                        |
| onnxruntime                        | 1.23.0          | MIT License                                                                                      | https://onnxruntime.ai                                                                                      |
| open_clip_torch                    | 3.2.0           | MIT License                                                                                      | https://github.com/mlfoundations/open_clip                                                                  |
| openai                             | 2.21.0          | Apache Software License                                                                          | https://github.com/openai/openai-python                                                                     |
| opencensus                         | 0.11.4          | Apache Software License                                                                          | https://github.com/census-instrumentation/opencensus-python                                                 |
| opencensus-context                 | 0.2.dev0        | Apache Software License                                                                          | https://github.com/census-instrumentation/opencensus-python/tree/master/context/opencensus-context          |
| opendal                            | 0.46.0          | Apache-2.0                                                                                       | https://opendal.apache.org/                                                                                 |
| opentelemetry-api                  | 1.40.0          | Apache-2.0                                                                                       | https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-api                          |
| opentelemetry-exporter-prometheus  | 0.61b0          | Apache-2.0                                                                                       | https://github.com/open-telemetry/opentelemetry-python/tree/main/exporter/opentelemetry-exporter-prometheus |
| opentelemetry-proto                | 1.40.0          | Apache-2.0                                                                                       | https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-proto                        |
| opentelemetry-sdk                  | 1.40.0          | Apache-2.0                                                                                       | https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-sdk                          |
| opentelemetry-semantic-conventions | 0.61b0          | Apache-2.0                                                                                       | https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-semantic-conventions         |
| orjson                             | 3.11.7          | MPL-2.0 AND (Apache-2.0 OR MIT)                                                                  | https://github.com/ijl/orjson                                                                               |
| overrides                          | 7.7.0           | Apache License, Version 2.0                                                                      | https://github.com/mkorpela/overrides                                                                       |
| packaging                          | 26.0            | Apache-2.0 OR BSD-2-Clause                                                                       | https://github.com/pypa/packaging                                                                           |
| paginate                           | 0.5.7           | MIT License                                                                                      | https://github.com/Signum/paginate                                                                          |
| pandas                             | 2.3.3           | BSD License                                                                                      | https://pandas.pydata.org                                                                                   |
| pandocfilters                      | 1.5.1           | BSD License                                                                                      | http://github.com/jgm/pandocfilters                                                                         |
| parso                              | 0.8.6           | MIT License                                                                                      | https://github.com/davidhalter/parso                                                                        |
| pathspec                           | 1.0.4           | Mozilla Public License 2.0 (MPL 2.0)                                                             | UNKNOWN                                                                                                     |
| pexpect                            | 4.9.0           | ISC License (ISCL)                                                                               | https://pexpect.readthedocs.io/                                                                             |
| pillow                             | 12.1.1          | MIT-CMU                                                                                          | https://python-pillow.github.io                                                                             |
| platformdirs                       | 4.9.2           | MIT                                                                                              | https://github.com/tox-dev/platformdirs                                                                     |
| pluggy                             | 1.6.0           | MIT License                                                                                      | UNKNOWN                                                                                                     |
| polars                             | 1.38.1          | MIT License                                                                                      | https://www.pola.rs/                                                                                        |
| polars-runtime-32                  | 1.38.1          | MIT License                                                                                      | https://www.pola.rs/                                                                                        |
| prometheus_client                  | 0.24.1          | Apache-2.0 AND BSD-2-Clause                                                                      | https://github.com/prometheus/client_python                                                                 |
| prompt_toolkit                     | 3.0.52          | BSD License                                                                                      | https://github.com/prompt-toolkit/python-prompt-toolkit                                                     |
| propcache                          | 0.4.1           | Apache Software License                                                                          | https://github.com/aio-libs/propcache                                                                       |
| proto-plus                         | 1.27.1          | Apache Software License                                                                          | https://github.com/googleapis/proto-plus-python                                                             |
| protobuf                           | 6.33.5          | 3-Clause BSD License                                                                             | https://developers.google.com/protocol-buffers/                                                             |
| psutil                             | 7.2.2           | BSD-3-Clause                                                                                     | https://github.com/giampaolo/psutil                                                                         |
| ptyprocess                         | 0.7.0           | ISC License (ISCL)                                                                               | https://github.com/pexpect/ptyprocess                                                                       |
| pure_eval                          | 0.2.3           | MIT License                                                                                      | http://github.com/alexmojaki/pure_eval                                                                      |
| py-cpuinfo                         | 9.0.0           | MIT License                                                                                      | https://github.com/workhorsy/py-cpuinfo                                                                     |
| py-spy                             | 0.4.1           | MIT License                                                                                      | https://github.com/benfred/py-spy                                                                           |
| pyarrow                            | 20.0.0          | Apache Software License                                                                          | https://arrow.apache.org/                                                                                   |
| pyarrow-stubs                      | 20.0.0.20251215 | BSD-2-Clause                                                                                     | https://github.com/zen-xu/pyarrow-stubs                                                                     |
| pyasn1                             | 0.6.2           | BSD-2-Clause                                                                                     | https://github.com/pyasn1/pyasn1                                                                            |
| pyasn1_modules                     | 0.4.2           | BSD License                                                                                      | https://github.com/pyasn1/pyasn1-modules                                                                    |
| pybase64                           | 1.4.2           | BSD License                                                                                      | https://github.com/mayeut/pybase64                                                                          |
| pycparser                          | 3.0             | BSD-3-Clause                                                                                     | https://github.com/eliben/pycparser                                                                         |
| pydantic                           | 2.13.0b1        | MIT                                                                                              | https://github.com/pydantic/pydantic                                                                        |
| pydantic-settings                  | 2.13.1          | MIT                                                                                              | https://github.com/pydantic/pydantic-settings                                                               |
| pydantic_core                      | 2.42.0          | MIT                                                                                              | https://github.com/pydantic/pydantic-core                                                                   |
| pylance                            | 3.1.0b2         | Apache Software License                                                                          | UNKNOWN                                                                                                     |
| pymdown-extensions                 | 10.21           | MIT                                                                                              | https://github.com/facelessuser/pymdown-extensions                                                          |
| pypdf                              | 6.8.0           | BSD-3-Clause                                                                                     | https://github.com/py-pdf/pypdf                                                                             |
| pyright                            | 1.1.408         | MIT                                                                                              | https://github.com/RobertCraigie/pyright-python                                                             |
| pytest                             | 9.0.2           | MIT                                                                                              | https://docs.pytest.org/en/latest/                                                                          |
| pytest-asyncio                     | 1.3.0           | Apache-2.0                                                                                       | https://github.com/pytest-dev/pytest-asyncio                                                                |
| pytest-benchmark                   | 5.2.3           | BSD-2-Clause                                                                                     | https://pytest-benchmark.readthedocs.io/en/latest/changelog.html                                            |
| pytest-cov                         | 7.0.0           | MIT                                                                                              | https://pytest-cov.readthedocs.io/en/latest/changelog.html                                                  |
| pytest-sugar                       | 1.1.1           | BSD License                                                                                      | https://github.com/Teemu/pytest-sugar                                                                       |
| pytest-timeout                     | 2.4.0           | DFSG approved; MIT License                                                                       | https://github.com/pytest-dev/pytest-timeout                                                                |
| pytest-xdist                       | 3.8.0           | MIT                                                                                              | https://github.com/pytest-dev/pytest-xdist                                                                  |
| python-dateutil                    | 2.9.0.post0     | Apache Software License; BSD License                                                             | https://github.com/dateutil/dateutil                                                                        |
| python-dotenv                      | 1.2.1           | BSD-3-Clause                                                                                     | https://github.com/theskumar/python-dotenv                                                                  |
| python-json-logger                 | 4.0.0           | BSD License                                                                                      | https://nhairs.github.io/python-json-logger                                                                 |
| pytz                               | 2025.2          | MIT License                                                                                      | http://pythonhosted.org/pytz                                                                                |
| pyyaml_env_tag                     | 1.1             | MIT                                                                                              | https://github.com/waylan/pyyaml-env-tag                                                                    |
| pyzmq                              | 27.1.0          | BSD License                                                                                      | https://pyzmq.readthedocs.org                                                                               |
| questionary                        | 2.1.1           | MIT License                                                                                      | https://github.com/tmbo/questionary                                                                         |
| ray                                | 2.54.0          | Apache 2.0                                                                                       | https://github.com/ray-project/ray                                                                          |
| referencing                        | 0.37.0          | MIT                                                                                              | https://github.com/python-jsonschema/referencing                                                            |
| regex                              | 2026.2.19       | Apache-2.0 AND CNRI-Python                                                                       | https://github.com/mrabarnett/mrab-regex                                                                    |
| requests                           | 2.32.5          | Apache Software License                                                                          | https://requests.readthedocs.io                                                                             |
| requests-oauthlib                  | 2.0.0           | BSD License                                                                                      | https://github.com/requests/requests-oauthlib                                                               |
| requests-toolbelt                  | 1.0.0           | Apache Software License                                                                          | https://toolbelt.readthedocs.io/                                                                            |
| rfc3339-validator                  | 0.1.4           | MIT License                                                                                      | https://github.com/naimetti/rfc3339-validator                                                               |
| rfc3986-validator                  | 0.1.1           | MIT License                                                                                      | https://github.com/naimetti/rfc3986-validator                                                               |
| rfc3987-syntax                     | 1.1.0           | MIT                                                                                              | https://github.com/willynilly/rfc3987-syntax                                                                |
| rich                               | 14.3.3          | MIT License                                                                                      | https://github.com/Textualize/rich                                                                          |
| rich-click                         | 1.9.7           | MIT License                                                                                      | https://github.com/ewels/rich-click                                                                         |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | Copyright (c) 2022 Phil Ewels                                                                    |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | Permission is hereby granted, free of charge, to any person obtaining a copy                     |                                                                                                             |
|                                    |                 | of this software and associated documentation files (the "Software"), to deal                    |                                                                                                             |
|                                    |                 | in the Software without restriction, including without limitation the rights                     |                                                                                                             |
|                                    |                 | to use, copy, modify, merge, publish, distribute, sublicense, and/or sell                        |                                                                                                             |
|                                    |                 | copies of the Software, and to permit persons to whom the Software is                            |                                                                                                             |
|                                    |                 | furnished to do so, subject to the following conditions:                                         |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | The above copyright notice and this permission notice shall be included in all                   |                                                                                                             |
|                                    |                 | copies or substantial portions of the Software.                                                  |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR                       |                                                                                                             |
|                                    |                 | IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,                         |                                                                                                             |
|                                    |                 | FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE                      |                                                                                                             |
|                                    |                 | AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER                           |                                                                                                             |
|                                    |                 | LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,                    |                                                                                                             |
|                                    |                 | OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE                    |                                                                                                             |
|                                    |                 | SOFTWARE.                                                                                        |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
| rpds-py                            | 0.30.0          | MIT                                                                                              | https://github.com/crate-py/rpds                                                                            |
| rsa                                | 4.7.2           | Apache Software License                                                                          | https://stuvel.eu/rsa                                                                                       |
| ruff                               | 0.15.2          | MIT License                                                                                      | https://docs.astral.sh/ruff                                                                                 |
| s3transfer                         | 0.16.0          | Apache Software License                                                                          | https://github.com/boto/s3transfer                                                                          |
| safetensors                        | 0.7.0           | Apache Software License                                                                          | https://github.com/huggingface/safetensors                                                                  |
| scikit-learn                       | 1.8.0           | BSD-3-Clause                                                                                     | https://scikit-learn.org                                                                                    |
| scipy                              | 1.17.1          | BSD License                                                                                      | https://scipy.org/                                                                                          |
| sentence-transformers              | 5.1.1           | Apache Software License                                                                          | https://www.SBERT.net                                                                                       |
| six                                | 1.17.0          | MIT License                                                                                      | https://github.com/benjaminp/six                                                                            |
| smart_open                         | 7.5.1           | MIT License                                                                                      | https://github.com/piskvorky/smart_open                                                                     |
| sniffio                            | 1.3.1           | Apache Software License; MIT License                                                             | https://github.com/python-trio/sniffio                                                                      |
| soundfile                          | 0.13.1          | BSD License                                                                                      | https://github.com/bastibe/python-soundfile                                                                 |
| soupsieve                          | 2.8.3           | MIT                                                                                              | https://github.com/facelessuser/soupsieve                                                                   |
| stack-data                         | 0.6.3           | MIT License                                                                                      | http://github.com/alexmojaki/stack_data                                                                     |
| sympy                              | 1.14.0          | BSD License                                                                                      | https://sympy.org                                                                                           |
| tenacity                           | 9.1.4           | Apache Software License                                                                          | https://github.com/jd/tenacity                                                                              |
| termcolor                          | 3.3.0           | MIT                                                                                              | https://github.com/termcolor/termcolor                                                                      |
| terminado                          | 0.18.1          | BSD License                                                                                      | https://github.com/jupyter/terminado                                                                        |
| textual                            | 1.0.0           | MIT License                                                                                      | https://github.com/Textualize/textual                                                                       |
| textual-serve                      | 1.1.3           | MIT                                                                                              | https://github.com/Textualize/textual-serve                                                                 |
| threadpoolctl                      | 3.6.0           | BSD License                                                                                      | https://github.com/joblib/threadpoolctl                                                                     |
| timm                               | 1.0.25          | Apache Software License                                                                          | https://github.com/huggingface/pytorch-image-models                                                         |
| tinycss2                           | 1.4.0           | BSD License                                                                                      | https://www.courtbouillon.org/tinycss2                                                                      |
| tokenizers                         | 0.22.2          | Apache Software License                                                                          | https://github.com/huggingface/tokenizers                                                                   |
| toml                               | 0.10.2          | MIT License                                                                                      | https://github.com/uiri/toml                                                                                |
| tomlkit                            | 0.14.0          | MIT License                                                                                      | https://github.com/sdispater/tomlkit                                                                        |
| torch                              | 2.10.0          | BSD-3-Clause                                                                                     | https://pytorch.org                                                                                         |
| torchcodec                         | 0.10.0          | BSD 3-Clause License                                                                             | UNKNOWN                                                                                                     |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | Copyright 2024 Meta                                                                              |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | Redistribution and use in source and binary forms, with or without modification,                 |                                                                                                             |
|                                    |                 | are permitted provided that the following conditions are met:                                    |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | 1. Redistributions of source code must retain the above copyright notice,this list               |                                                                                                             |
|                                    |                 | of conditions and the following disclaimer.                                                      |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | 2. Redistributions in binary form must reproduce the above copyright notice, this                |                                                                                                             |
|                                    |                 | list of conditions and the following disclaimer in the documentation                             |                                                                                                             |
|                                    |                 | and/or other materials provided with the distribution.                                           |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | 3. Neither the name of the copyright holder nor the names of its contributors may                |                                                                                                             |
|                                    |                 | be used to endorse or promote products derived from this software without specific               |                                                                                                             |
|                                    |                 | prior written permission.                                                                        |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
|                                    |                 | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS “AS IS” AND ANY              |                                                                                                             |
|                                    |                 | EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES             |                                                                                                             |
|                                    |                 | OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT              |                                                                                                             |
|                                    |                 | SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,                   |                                                                                                             |
|                                    |                 | INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED             |                                                                                                             |
|                                    |                 | TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR               |                                                                                                             |
|                                    |                 | BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN                 |                                                                                                             |
|                                    |                 | CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN               |                                                                                                             |
|                                    |                 | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH              |                                                                                                             |
|                                    |                 | DAMAGE.                                                                                          |                                                                                                             |
|                                    |                 |                                                                                                  |                                                                                                             |
| torchvision                        | 0.25.0          | BSD                                                                                              | https://github.com/pytorch/vision                                                                           |
| tornado                            | 6.5.4           | Apache Software License                                                                          | http://www.tornadoweb.org/                                                                                  |
| tqdm                               | 4.67.3          | MPL-2.0 AND MIT                                                                                  | https://tqdm.github.io                                                                                      |
| traitlets                          | 5.14.3          | BSD License                                                                                      | https://github.com/ipython/traitlets                                                                        |
| transformers                       | 4.57.1          | Apache Software License                                                                          | https://github.com/huggingface/transformers                                                                 |
| ttstokenizer                       | 1.1.0           | Apache 2.0: http://www.apache.org/licenses/LICENSE-2.0                                           | https://github.com/neuml/ttstokenizer                                                                       |
| typeguard                          | 4.5.1           | MIT                                                                                              | UNKNOWN                                                                                                     |
| types-awscrt                       | 0.31.2          | MIT License                                                                                      | https://github.com/youtype/types-awscrt                                                                     |
| types-s3transfer                   | 0.16.0          | MIT                                                                                              | https://github.com/youtype/types-s3transfer                                                                 |
| typing-inspection                  | 0.4.2           | MIT                                                                                              | https://github.com/pydantic/typing-inspection                                                               |
| typing_extensions                  | 4.15.0          | PSF-2.0                                                                                          | https://github.com/python/typing_extensions                                                                 |
| tzdata                             | 2025.3          | Apache-2.0                                                                                       | https://github.com/python/tzdata                                                                            |
| uc-micro-py                        | 1.0.3           | MIT License                                                                                      | https://github.com/tsutsu3/uc.micro-py                                                                      |
| uri-template                       | 1.3.0           | MIT License                                                                                      | https://gitlab.linss.com/open-source/python/uri-template                                                    |
| urllib3                            | 2.6.3           | MIT                                                                                              | https://github.com/urllib3/urllib3/blob/main/CHANGES.rst                                                    |
| uuid_utils                         | 0.14.1          | BSD-3-Clause                                                                                     | https://github.com/aminalaee/uuid-utils                                                                     |
| virtualenv                         | 20.39.0         | MIT                                                                                              | https://github.com/pypa/virtualenv                                                                          |
| watchdog                           | 6.0.0           | Apache Software License                                                                          | https://github.com/gorakhargosh/watchdog                                                                    |
| wcmatch                            | 10.1            | MIT                                                                                              | https://github.com/facelessuser/wcmatch                                                                     |
| webcolors                          | 25.10.0         | BSD License                                                                                      | UNKNOWN                                                                                                     |
| webencodings                       | 0.5.1           | BSD License                                                                                      | https://github.com/SimonSapin/python-webencodings                                                           |
| websocket-client                   | 1.9.0           | Apache Software License                                                                          | https://github.com/websocket-client/websocket-client.git                                                    |
| websockets                         | 15.0.1          | BSD License                                                                                      | https://github.com/python-websockets/websockets                                                             |
| widgetsnbextension                 | 4.0.15          | BSD License                                                                                      | http://jupyter.org                                                                                          |
| wrapt                              | 2.1.1           | BSD-2-Clause                                                                                     | https://github.com/GrahamDumpleton/wrapt                                                                    |
| xxhash                             | 3.6.0           | BSD License                                                                                      | https://github.com/ifduyue/python-xxhash                                                                    |
| yarl                               | 1.22.0          | Apache Software License                                                                          | https://github.com/aio-libs/yarl                                                                            |
| zipp                               | 3.23.0          | MIT                                                                                              | https://github.com/jaraco/zipp                                                                              |
| zstandard                          | 0.25.0          | BSD-3-Clause                                                                                     | https://github.com/indygreg/python-zstandard                                                                |
